@@ -54,6 +54,11 @@ def setup( config_user = None ) :
 
 
 def preprocess( ) :
+
+    # FIXME TODO hack to flush alt config - see endpoint/url for public sapiomnibus etc...
+    global config_alt
+    config_alt = { }
+
     handle_key_fromcontainer( )
     unpack_key( )
     handle_sslverify_fornumericip( )
@@ -98,26 +103,28 @@ def checkup_workspacedir( ) :
         set_key( "sys/workspacedir" , "/tmp/sapiadapter" )
 
 def handle_key_fromcontainer( ) :
-    
 
     if( get_key( "endpoint/key" ) ) :
         return
 
-    if not "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" in os.environ : return
+    if not "_CONTAINER_LOCAL_APPENDPOINTKEY" in os.environ : return
 
-    endpoint_key = os.environ[ "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" ]
+    endpoint_key = os.environ[ "_CONTAINER_LOCAL_APPENDPOINTKEY" ]
+    s_log.write( "Found _CONTAINER_LOCAL_APPENDPOINTKEY" )
 
-    if endpoint_key.endswith( "_LOCAL_CONFIGENDPOINTKEY_" ) : return
+    if endpoint_key.endswith( "_LOCAL_APPENDPOINTKEY_" ) : return
 
     #set_key_alt( "endpoint/key" , endpoint_key ) 
     set_key( "endpoint/key" , endpoint_key ) 
-
-
-
+    s_log.write( "Using _CONTAINER_LOCAL_APPENDPOINTKEY" )
 
 def handle_key_public( ) :
 
-    if( get_key( "endpoint/url"  ) != False ) : return
+    endpoint_url = get_key( "endpoint/url"  )
+
+    #s_log.write( get_key( "endpoint/url"  ) )
+
+    if( not ( endpoint_url == None or endpoint_url == False ) ) : return
 
     set_key_alt( "endpoint/url" , "https://sapiomnibus-public.sparc.space" )
 
@@ -161,6 +168,7 @@ def unpack_key( ) :
     #s_log.write(endpoint_key)
 
     if( not endpoint_key ) :
+        s_log.write( "not endpoint_key" )
         return
 
     ########################################################
@@ -323,6 +331,17 @@ def load_from_file( cp ) :
 
 ################################################################
 
+# Use this when updating keys e.g. KEY otherwise session gets clobbered which may be required for thread safety
+def init_update( config_user ) :
+
+    global config
+
+    config.update( config_user )
+    config[ "/config/init/from" ] = "config_user"
+    preprocess( )
+    return( True ) 
+
+
 def init( config_user = None ) :
 
     global config
@@ -347,7 +366,7 @@ def init( config_user = None ) :
     if( config_user ) :
         config.update( config_user )
         config[ "/config/init/from" ] = "config_user"
-        preprocess()
+        preprocess( )
         return( True ) 
 
     ################################################################
