@@ -25,6 +25,8 @@ import shutil
 import gzip
 import inspect
 
+import threading
+
 from datetime import datetime , timedelta
 
 import datetime as _dt
@@ -441,6 +443,12 @@ def file_getcontent( fn , scp ) :
 
 
 def path_stem( p ) :
-    fn=Path(p).stem
-    return(fn)
+    fn = Path( p ).stem
+    return( fn )
 
+################
+
+def thread_get_id( ) :
+    return( threading.get_ident( ) ) 
+   
+ 
