@@ -101,6 +101,10 @@ def server( runner , debug_errorprexit = False ) :
             continue
 
         #####################################################
+        context =  s_config.get_key( "header_context" )
+        s_log.write( context )
+        #qparams = context[ "qparams" ]
+        #####################################################
 
         params = s_db.meta_read( "_params" )
 
@@ -181,6 +185,12 @@ def run( params = { } , wait_timeout = 60 ) :
     #    s_log.write( "NOT READY" )
     #    return( False )
 
+
+    tid = s_util.thread_get_id()
+
+
+
+
     if( not isinstance( params , ( dict ) ) ) :
         s_log.write( "false params dict" )
         return( False )
